type Child = string | Node | null | undefined | readonly Child[]

export default function crelt(elt: string | HTMLElement, attrs: {[attr: string]: any}, ...children: Child[]): HTMLElement
export default function crelt(elt: string | HTMLElement, ...children: Child[]): HTMLElement
